Index: src/math.js |
diff --git a/src/math.js b/src/math.js |
index b5a6d1811757aaaa7b0f35fc863b4a471e47b341..31306e79d18e1e98cba7e2ee7f697ef303f91543 100644 |
--- a/src/math.js |
+++ b/src/math.js |
@@ -195,9 +195,8 @@ function MathTan(x) { |
// ------------------------------------------------------------------- |
-function SetUpMath() { |
- %CheckIsBootstrapping(); |
- // Set up math constants. |
+function SetupMath() { |
+ // Setup math constants. |
// ECMA-262, section 15.8.1.1. |
%OptimizeObjectForAddingMultipleProperties($Math, 8); |
%SetProperty($Math, |
@@ -237,7 +236,7 @@ function SetUpMath() { |
DONT_ENUM | DONT_DELETE | READ_ONLY); |
%ToFastProperties($Math); |
// Set up non-enumerable functions of the Math object and |
// set their names. |
InstallFunctionsOnHiddenPrototype($Math, DONT_ENUM, $Array( |
"random", MathRandom, |
@@ -259,6 +258,7 @@ function SetUpMath() { |
"max", MathMax, |
"min", MathMin |
)); |
-} |
+}; |
+ |
-SetUpMath(); |
+SetupMath(); |
@@ -237,7 +236,7 @@ function SetUpMath() { |
DONT_ENUM | DONT_DELETE | READ_ONLY); |
%ToFastProperties($Math); |
- // Set up non-enumerable functions of the Math object and |
+ // Setup non-enumerable functions of the Math object and |
// set their names. |
InstallFunctionsOnHiddenPrototype($Math, DONT_ENUM, $Array( |